@@ -11,6 +11,7 @@ import asyncclick as click
 
 from . import __version__
 from .ble import repl_loop, scanner, send_text
+from .gui import App
 
 
 def ble_receive_callback(data: bytes):
@@ -137,6 +138,30 @@ async def repl(ctx, device, ble_connection_timeout):
         click.echo(click.style(e, fg="red"))
 
 
+@cli.command()
+@click.option(
+    "--device",
+    required=True,
+    type=str,
+    envvar="FREAKBLE_DEVICE",
+    help="ble device address",
+)
+@click.option(
+    "--ble-connection-timeout",
+    default=10,
+    show_default="10 secs",
+    type=float,
+    help="BLE connection timeout",
+)
+@click.pass_context
+async def gui(ctx, device, ble_connection_timeout):
+    """Start freakble GUI."""
+
+    app = App()
+    app.config(ctx.obj["ADAPTER"], device, ble_connection_timeout)
+    await app.run()
+
+
 @cli.command()
 async def version():
     """Return freakble version."""
